<?php

namespace Drupal\reactify_auth\Authentication\Provider;

use Drupal\Core\Authentication\AuthenticationProviderInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\user\UserAuthInterface;
use Symfony\Component\HttpFoundation\Request;


/**
 * Authentication provider.
 */
class JsonAuth implements AuthenticationProviderInterface {
  /**
   * Config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * User auth service.
   *
   * @var \Drupal\user\UserAuthInterface
   */
  protected $userAuth;

  /**
   * Entity type manager.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * Construct authentification provider object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface
   * @param \Drupal\user\UserAuthInterface
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  public function __construct(ConfigFactoryInterface $config_factory, UserAuthInterface $user_auth, EntityTypeManagerInterface $entity_type_manager) {
    $this->configFactory = $config_factory;
    $this->userAuth = $user_auth;
    $this->entityTypeManager = $entity_type_manager;
  }

  public function applies(Request $request) {
    // TODO: Implement applies() method.
    $content = json_decode($request->getContent());
    return isset($content->name, $content->pass) && !empty($content->name) && !empty($content->pass) && !isset($content->mail);
  }

  public function authenticate(Request $request) {
    // TODO: Implement authenticate() method.
    $content = json_decode($request->getContent());

    $username = $content->name;
    $password = $content->pass;

    $accounts = $this->entityTypeManager->getStorage('user')->loadByProperties(['name' => $username]);
    $account = reset($accounts);

    if ($account) {
      $identifier = $account->id();
    } else {
      $identifier = $account->id() . '-' . $request->getClientIp();
    }

    $uid = $this->userAuth->authenticate($username, $password);

    if ($uid) {
      return $this->entityTypeManager->getStorage('user')->load($uid);
    }
    return [];
  }

}