<?php

namespace Drupal\reactify_dashboard_stats\Plugin\rest\Resource;

use Drupal\rest\Plugin\ResourceBase;
use Drupal\rest\ResourceResponse;
use Drupal\Component\Plugin\Exception\PluginNotFoundException;

/**
 * Provides Dashboard statistics endpoint.
 *
 * @RestResource (
 *   id = "reactify_dashboard_stats",
 *   label = @Translation("Dashboard statistics"),
 *   uri_paths = {
 *     "canonical" = "/api/dashboard_stats"
 *   }
 * )
 */

class DashboardStatsResource extends ResourceBase {

  // User count.
  public function getUsersTotal() {
    $usersQuery = \Drupal::entityQuery('user');
    $usersTotal = $usersQuery->count()->execute();
    return $usersTotal;
    // var_dump($usersTotal);
    //die();
  }

  // Client count.
  protected function getClientsTotal() {
    // TODO add check if entity type exists.
    $clientsQuery = \Drupal::entityQuery('client');
    $clientsTotal = $clientsQuery->count()->execute();
    return $clientsTotal;
  }

  // Entity count.
  protected function countTotal($entity_type) {
    // TODO add check if entity type exists.
    $resultQuery = \Drupal::entityQuery($entity_type);
    $resultTotal = $resultQuery->count()->execute();
    return $resultTotal;
  }


  public function get() {

    // Stats array.
    $stats = [];
    $usersTotal = $this->countTotal('user');
    $contentCount = $this->countTotal('node');
    $commentCount = $this->countTotal('comment');
    try {
      $clientsTotal = $this->countTotal('client');
    }
    catch (PluginNotFoundException $e) {
      $clientsTotal = null;
    };



    if (!empty($usersTotal)) {
      $stats['usersTotal'] = $usersTotal;
    }

    if (!empty($contentCount)) {
      $stats['contentTotal'] = $contentCount;
    }

    if (!empty($commentCount)) {
      $stats['commentTotal'] = $commentCount;
    }

    if (!empty($clientsTotal)) {
      $stats['clientsTotal'] = $clientsTotal;
    }

    $response = new ResourceResponse($stats);
    $response->addCacheableDependency($stats);
    return $response;
  }
}